# Start with `jaxspec`

<div class="grid cards" markdown>

-   [__:material-clock-fast:{ .lg .middle } `jaxspec` fitting speedrun__](fitting_example.md)

    ---

    A quick overview of the general fitting workflow.


-   [__Load your data in `jaxspec`__](load_data.ipynb)

    ---

    How to load your data in `jaxspec` using a PHA file.

-   [__Model building made easy__](build_model.md)

    ---

    Combine components to build a model.


-   [__Generate mock data__](fakeits.md)

    ---

    Use the `fakeit` function to generate mock data.


</div>

# Advanced examples

<div class="grid cards" markdown>

-   [__Add a background__](background.md)

    ---

    Add an observed background in your spectral model.

-   [__Good practices for MCMC results__](work_with_arviz.ipynb)

    ---

    Use `arviz` to assess the quality of your fit


-   [__Interface with other frameworks__](external_samplers.ipynb)

    ---

    Use `jaxspec` likelihood in other packages


</div>